@@ -324,6 +324,7 @@ def configure_logging(
         config_file: str = None,
         fallback: bool = False,
         logger_name: str = 'root',
+        log_level: int = logging.INFO
 ):
     """ Sets up the custom logger. Loads the configuration
     from :paramref:`~configure_logging.config_file` using the
@@ -341,6 +342,9 @@ def configure_logging(
     logger_name : str, optional
         Logger name.
 
+    log_level: int, optional
+        Initial logging level, default is INFO (20).
+
     Raises
     ------
     :class:`configparser.Error`
@@ -525,6 +529,7 @@ def configure_logging(
 
     else:
         logger = logging.getLogger(name=logger_name)
+        logger.setLevel(log_level)
         logger.info('Logging system set up and running')
         logger.debug('Active handlers:')
         for handler in handlers_list:
