@@ -27,7 +27,7 @@ The module is based upon `this tutorial
 
 Attributes
 ----------
-buffer_size: int, 1024
+buffer_size: int, 4096
     Maximum length of a transmitted messages
 """
 
@@ -49,7 +49,7 @@ from lab_utils.custom_logging import getLogger, CustomLogger
 from .__project__ import __documentation__ as docs_url
 
 # Maximum length of transmitted messages
-buffer_size: int = 1024
+buffer_size: int = 4096
 
 
 class ArgumentParser(argparse.ArgumentParser):
@@ -137,14 +137,9 @@ class ArgumentParser(argparse.ArgumentParser):
             full_message += '    {:15}   {}\n'.format(sp.prog.split(' ')[1], sp.description)
 
             for action_group in sp._action_groups:   # noqa
-                # print(action_group.title)
-                # print(action_group.description)
                 for op in action_group._group_actions:   # noqa
                     if action_group.title == 'optional arguments':
                         desc = '[{}]'.format(op.option_strings[0])
-                    else:
-                        desc = op.option_strings[0]
-                    # print(desc)
                     full_message += '        {:15}    {}\n'.format(desc, op.help)
         full_message += '\n'
 
